@@ -1,30 +1,16 @@
-/********************************************************************
-Copyright 2014  Martin Gräßlin <mgraesslin@kde.org>
-Copyright 2018  David Edmundson <davidedmundson@kde.org>
+/*
+    SPDX-FileCopyrightText: 2014 Martin Gräßlin <mgraesslin@kde.org>
+    SPDX-FileCopyrightText: 2018 David Edmundson <davidedmundson@kde.org>
 
-This library is free software; you can redistribute it and/or
-modify it under the terms of the GNU Lesser General Public
-License as published by the Free Software Foundation; either
-version 2.1 of the License, or (at your option) version 3, or any
-later version accepted by the membership of KDE e.V. (or its
-successor approved by the membership of KDE e.V.), which shall
-act as a proxy defined in Section 6 of version 3 of the license.
-
-This library is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-Lesser General Public License for more details.
-
-You should have received a copy of the GNU Lesser General Public
-License along with this library.  If not, see <http://www.gnu.org/licenses/>.
-*********************************************************************/
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+*/
 #ifndef WAYLAND_REGISTRY_H
 #define WAYLAND_REGISTRY_H
 
 #include <QHash>
 #include <QObject>
 
-#include <KWayland/Client/kwaylandclient_export.h>
+#include "KWayland/Client/kwaylandclient_export.h"
 
 struct wl_compositor;
 struct wl_data_device_manager;
@@ -37,23 +23,17 @@ struct wl_shm;
 struct wl_subcompositor;
 struct wl_text_input_manager;
 struct zwp_text_input_manager_v2;
-struct _wl_fullscreen_shell;
 struct org_kde_kwin_appmenu_manager;
-struct org_kde_kwin_outputmanagement;
-struct org_kde_kwin_outputdevice;
 struct org_kde_kwin_fake_input;
-struct org_kde_kwin_idle;
-struct org_kde_kwin_remote_access_manager;
 struct org_kde_kwin_dpms_manager;
 struct org_kde_kwin_shadow_manager;
 struct org_kde_kwin_blur_manager;
 struct org_kde_kwin_contrast_manager;
 struct org_kde_kwin_slide_manager;
+struct org_kde_plasma_activation_feedback;
 struct org_kde_plasma_shell;
 struct org_kde_plasma_virtual_desktop_management;
 struct org_kde_plasma_window_management;
-struct org_kde_kwin_server_decoration_manager;
-struct org_kde_kwin_server_decoration_palette_manager;
 struct xdg_shell;
 struct zxdg_shell_v6;
 struct xdg_wm_base;
@@ -70,7 +50,6 @@ namespace KWayland
 {
 namespace Client
 {
-
 class AppMenuManager;
 class Compositor;
 class ConnectionThread;
@@ -79,12 +58,12 @@ class DpmsManager;
 class EventQueue;
 class FakeInput;
 class FullscreenShell;
-class OutputManagement;
-class OutputDevice;
 class Idle;
 class IdleInhibitManager;
+class Keystate;
 class RemoteAccessManager;
 class Output;
+class PlasmaActivationFeedback;
 class PlasmaShell;
 class PlasmaVirtualDesktopManagement;
 class PlasmaWindowManagement;
@@ -147,47 +126,41 @@ public:
      * object.
      **/
     enum class Interface {
-        Unknown,    ///< Refers to an Unknown interface
+        Unknown, ///< Refers to an Unknown interface
         Compositor, ///< Refers to the wl_compositor interface
-        Shell,      ///< Refers to the wl_shell interface
-        Seat,       ///< Refers to the wl_seat interface
-        Shm,        ///< Refers to the wl_shm interface
-        Output,     ///< Refers to the wl_output interface
-        FullscreenShell, ///< Refers to the _wl_fullscreen_shell interface
+        Shell, ///< Refers to the wl_shell interface
+        Seat, ///< Refers to the wl_seat interface
+        Shm, ///< Refers to the wl_shm interface
+        Output, ///< Refers to the wl_output interface
         SubCompositor, ///< Refers to the wl_subcompositor interface;
         DataDeviceManager, ///< Refers to the wl_data_device_manager interface
         PlasmaShell, ///< Refers to org_kde_plasma_shell interface
         PlasmaWindowManagement, ///< Refers to org_kde_plasma_window_management interface
-        Idle, ///< Refers to org_kde_kwin_idle_interface interface
         FakeInput, ///< Refers to org_kde_kwin_fake_input interface
         Shadow, ///< Refers to org_kde_kwin_shadow_manager interface
         Blur, ///< refers to org_kde_kwin_blur_manager interface
         Contrast, ///< refers to org_kde_kwin_contrast_manager interface
         Slide, ///< refers to org_kde_kwin_slide_manager
         Dpms, ///< Refers to org_kde_kwin_dpms_manager interface
-        OutputManagement, ///< Refers to the wl_data_device_manager interface
-        OutputDevice,     ///< Refers to the org_kde_kwin_outputdevice interface
-        ServerSideDecorationManager, ///< Refers to org_kde_kwin_server_decoration_manager
-        TextInputManagerUnstableV0, ///< Refers to wl_text_input_manager, @since 5.23
-        TextInputManagerUnstableV2, ///< Refers to zwp_text_input_manager_v2, @since 5.23
-        XdgShellUnstableV5, ///< Refers to xdg_shell (unstable version 5), @since 5.25
-        RelativePointerManagerUnstableV1, ///< Refers to zwp_relative_pointer_manager_v1, @since 5.28
-        PointerGesturesUnstableV1, ///< Refers to zwp_pointer_gestures_v1, @since 5.29
-        PointerConstraintsUnstableV1, ///< Refers to zwp_pointer_constraints_v1, @since 5.29
-        XdgExporterUnstableV2, ///< refers to zxdg_exporter_v2, @since 5.40
-        XdgImporterUnstableV2, ///< refers to zxdg_importer_v2, @since 5.40
-        XdgShellUnstableV6, ///< Refers to zxdg_shell_v6 (unstable version 6), @since 5.39
-        IdleInhibitManagerUnstableV1, ///< Refers to zwp_idle_inhibit_manager_v1 (unstable version 1), @since 5.41
-        AppMenu, ///Refers to org_kde_kwin_appmenu @since 5.42
-        ServerSideDecorationPalette, ///Refers to org_kde_kwin_server_decoration_palette_manager @since 5.42
-        RemoteAccessManager, ///< Refers to org_kde_kwin_remote_access_manager interface, @since 5.45
+        TextInputManagerUnstableV0, ///< Refers to wl_text_input_manager @since 5.23
+        TextInputManagerUnstableV2, ///< Refers to zwp_text_input_manager_v2 @since 5.23
+        XdgShellUnstableV5, ///< Refers to xdg_shell (unstable version 5) @since 5.25
+        RelativePointerManagerUnstableV1, ///< Refers to zwp_relative_pointer_manager_v1 @since 5.28
+        PointerGesturesUnstableV1, ///< Refers to zwp_pointer_gestures_v1 @since 5.29
+        PointerConstraintsUnstableV1, ///< Refers to zwp_pointer_constraints_v1 @since 5.29
+        XdgExporterUnstableV2, ///< refers to zxdg_exporter_v2 @since 5.40
+        XdgImporterUnstableV2, ///< refers to zxdg_importer_v2 @since 5.40
+        XdgShellUnstableV6, ///< Refers to zxdg_shell_v6 (unstable version 6) @since 5.39
+        IdleInhibitManagerUnstableV1, ///< Refers to zwp_idle_inhibit_manager_v1 (unstable version 1) @since 5.41
+        AppMenu, ///< Refers to org_kde_kwin_appmenu @since 5.42
         PlasmaVirtualDesktopManagement, ///< Refers to org_kde_plasma_virtual_desktop_management interface @since 5.52
-        XdgOutputUnstableV1, ///refers to zxdg_output_v1, @since 5.47
-        XdgShellStable, ///refers to xdg_wm_base @since 5.48
-        XdgDecorationUnstableV1, ///refers to zxdg_decoration_manager_v1, @since 5.54
+        XdgOutputUnstableV1, ///< refers to zxdg_output_v1 @since 5.47
+        XdgShellStable, ///< refers to xdg_wm_base @since 5.48
+        XdgDecorationUnstableV1, ///< refers to zxdg_decoration_manager_v1 @since 5.54
+        PlasmaActivationFeedback, ///< Refers to org_kde_plasma_activation_feedback interface, @since 5.83
     };
     explicit Registry(QObject *parent = nullptr);
-    virtual ~Registry();
+    ~Registry() override;
 
     /**
      * Releases the wl_registry interface.
@@ -291,7 +264,7 @@ public:
      * @returns All pairs of name and version of the given interface
      * @since 5.5
      **/
-    QVector<AnnouncedInterface> interfaces(Interface interface) const;
+    QList<AnnouncedInterface> interfaces(Interface interface) const;
 
     /**
      * @name Low-level bind methods for global interfaces.
@@ -333,22 +306,10 @@ public:
      * @see createShmPool
      **/
     wl_shm *bindShm(uint32_t name, uint32_t version) const;
-    /**
-     * Binds the org_kde_kwin_outputmanagement with @p name and @p version.
-     * If the @p name does not exist or is not for the outputmanagement interface,
-     * @c null will be returned.
-     *
-     * Prefer using createOutputManagement instead.
-     * @see createOutputManagement
-     **/
-    org_kde_kwin_outputmanagement *bindOutputManagement(uint32_t name, uint32_t version) const;
     /**
      * Binds the org_kde_kwin_outputdevice with @p name and @p version.
      * If the @p name does not exist or is not for the outputdevice interface,
      * @c null will be returned.
-     *
-     * Prefer using createOutputDevice instead.
-     * @see createOutputDevice
      **/
     wl_output *bindOutput(uint32_t name, uint32_t version) const;
     /**
@@ -360,26 +321,7 @@ public:
      * @see createSubCompositor
      **/
     wl_subcompositor *bindSubCompositor(uint32_t name, uint32_t version) const;
-    /**
-     * Binds the wl_output with @p name and @p version.
-     * If the @p name does not exist or is not for the output interface,
-     * @c null will be returned.
-     *
-     * Prefer using createOutput instead.
-     * @see createOutput
-     * @since 5.5
-     **/
-    org_kde_kwin_outputdevice *bindOutputDevice(uint32_t name, uint32_t version) const;
 
-    /**
-     * Binds the _wl_fullscreen_shell with @p name and @p version.
-     * If the @p name does not exist or is not for the fullscreen shell interface,
-     * @c null will be returned.
-     *
-     * Prefer using createFullscreenShell instead.
-     * @see createFullscreenShell
-     **/
-    _wl_fullscreen_shell *bindFullscreenShell(uint32_t name, uint32_t version) const;
     /**
      * Binds the wl_data_device_manager with @p name and @p version.
      * If the @p name does not exist or is not for the data device manager interface,
@@ -399,6 +341,16 @@ public:
      * @since 5.4
      **/
     org_kde_plasma_shell *bindPlasmaShell(uint32_t name, uint32_t version) const;
+    /**
+     * Binds the org_kde_plasma_activation_feedback with @p name and @p version.
+     * If the @p name does not exist or is not for the Plasma activation manager interface,
+     * @c null will be returned.
+     *
+     * Prefer using createPlasmaActivationFeedback instead.
+     * @see createPlasmaActivationFeedback
+     * @since 5.83
+     **/
+    org_kde_plasma_activation_feedback *bindPlasmaActivationFeedback(uint32_t name, uint32_t version) const;
     /**
      * Binds the org_kde_plasma_virtual_desktop_management with @p name and @p version.
      * If the @p name does not exist or is not for the Plasma Virtual desktop interface,
@@ -419,26 +371,6 @@ public:
      * @since 5.46
      **/
     org_kde_plasma_window_management *bindPlasmaWindowManagement(uint32_t name, uint32_t version) const;
-    /**
-     * Binds the org_kde_kwin_idle with @p name and @p version.
-     * If the @p name does not exist or is not for the idle interface,
-     * @c null will be returned.
-     *
-     * Prefer using createIdle instead.
-     * @see createIdle
-     * @since 5.4
-     **/
-    org_kde_kwin_idle *bindIdle(uint32_t name, uint32_t version) const;
-    /**
-     * Binds the org_kde_kwin_remote_access_manager with @p name and @p version.
-     * If the @p name does not exist or is not for the idle interface,
-     * @c null will be returned.
-     *
-     * Prefer using createRemoteAccessManager instead.
-     * @see createRemoteAccessManager
-     * @since 5.45
-     **/
-    org_kde_kwin_remote_access_manager *bindRemoteAccessManager(uint32_t name, uint32_t version) const;
     /**
      * Binds the org_kde_kwin_fake_input with @p name and @p version.
      * If the @p name does not exist or is not for the fake input interface,
@@ -488,7 +420,7 @@ public:
      * @see createSlideManager
      * @since 5.5
      **/
-    org_kde_kwin_slide_manager * bindSlideManager(uint32_t name, uint32_t version) const;
+    org_kde_kwin_slide_manager *bindSlideManager(uint32_t name, uint32_t version) const;
     /**
      * Binds the org_kde_kwin_dpms_manager with @p name and @p version.
      * If the @p name does not exist or is not for the dpms manager interface,
@@ -499,16 +431,6 @@ public:
      * @since 5.5
      **/
     org_kde_kwin_dpms_manager *bindDpmsManager(uint32_t name, uint32_t version) const;
-    /**
-     * Binds the org_kde_kwin_server_decoration_manager with @p name and @p version.
-     * If the @p name does not exist or is not for the server side decoration manager interface,
-     * @c null will be returned.
-     *
-     * Prefer using createServerSideDecorationManager instead.
-     * @see createServerSideDecorationManager
-     * @since 5.6
-     **/
-    org_kde_kwin_server_decoration_manager *bindServerSideDecorationManager(uint32_t name, uint32_t version) const;
     /**
      * Binds the wl_text_input_manager with @p name and @p version.
      * If the @p name does not exist or is not for the text input interface in unstable version 0,
@@ -633,17 +555,6 @@ public:
      **/
     org_kde_kwin_appmenu_manager *bindAppMenuManager(uint32_t name, uint32_t version) const;
 
-    /**
-     * Binds the org_kde_kwin_server_decoration_palette_manager with @p name and @p version.
-     * If the @p name does not exist or is not for the server side decoration palette manager interface,
-     * @c null will be returned.
-     *
-     * Prefer using createServerSideDecorationPaletteManager instead.
-     * @see createServerSideDecorationPaletteManager
-     * @since 5.42
-     **/
-    org_kde_kwin_server_decoration_palette_manager *bindServerSideDecorationPaletteManager(uint32_t name, uint32_t version) const;
-
     /**
      * Binds the zxdg_output_v1 with @p name and @p version.
      * If the @p name does not exist,
@@ -762,54 +673,6 @@ public:
      * @returns The created Output.
      **/
     Output *createOutput(quint32 name, quint32 version, QObject *parent = nullptr);
-    /**
-     * Creates an KWinOutputManagement and sets it up to manage the interface identified
-     * by @p name and @p version.
-     *
-     * Note: in case @p name is invalid or isn't for the wl_output interface,
-     * the returned KWinConnectors will not be valid. Therefore it's recommended to call
-     * isValid on the created instance.
-     *
-     * @param name The name of the org_kde_kwin_outputmanagement interface to bind
-     * @param version The version or the org_kde_kwin_outputmanagement interface to use
-     * @param parent The parent for KWinOutputManagement
-     *
-     * @returns The created KWinOutputManagement.
-     * @since 5.5
-     **/
-    OutputManagement *createOutputManagement(quint32 name, quint32 version, QObject *parent = nullptr);
-    /**
-     * Creates an OutputDevice and sets it up to manage the interface identified by
-     * @p name and @p version.
-     *
-     * Note: in case @p name is invalid or isn't for the org_kde_kwin_outputdevice interface,
-     * the returned OutputDevice will not be valid. Therefore it's recommended to call
-     * isValid on the created instance.
-     *
-     * @param name The name of the org_kde_kwin_outputdevice interface to bind
-     * @param version The version or the org_kde_kwin_outputdevice interface to use
-     * @param parent The parent for OutputDevice
-     *
-     * @returns The created Output.
-     * @since 5.5
-     **/
-    OutputDevice *createOutputDevice(quint32 name, quint32 version, QObject *parent = nullptr);
-    /**
-     * Creates a FullscreenShell and sets it up to manage the interface identified by
-     * @p name and @p version.
-     *
-     * Note: in case @p name is invalid or isn't for the _wl_fullscreen_shell interface,
-     * the returned FullscreenShell will not be valid. Therefore it's recommended to call
-     * isValid on the created instance.
-     *
-     * @param name The name of the _wl_fullscreen_shell interface to bind
-     * @param version The version or the _wl_fullscreen_shell interface to use
-     * @param parent The parent for FullscreenShell
-     *
-     * @returns The created FullscreenShell.
-     * @since 5.5
-     **/
-    FullscreenShell *createFullscreenShell(quint32 name, quint32 version, QObject *parent = nullptr);
     /**
      * Creates a DataDeviceManager and sets it up to manage the interface identified by
      * @p name and @p version.
@@ -841,6 +704,22 @@ public:
      * @since 5.4
      **/
     PlasmaShell *createPlasmaShell(quint32 name, quint32 version, QObject *parent = nullptr);
+    /**
+     * Creates a PlasmaActivationFeedback and sets it up to manage the interface identified by
+     * @p name and @p version.
+     *
+     * Note: in case @p name is invalid or isn't for the org_kde_plasma_activation_feedback interface,
+     * the returned PlasmaActivationFeedback will not be valid. Therefore it's recommended to call
+     * isValid on the created instance.
+     *
+     * @param name The name of the org_kde_plasma_activation_feedback interface to bind
+     * @param version The version or the org_kde_plasma_activation_feedback interface to use
+     * @param parent The parent for PlasmaActivationFeedback
+     *
+     * @returns The created PlasmaActivationFeedback.
+     * @since 5.83
+     **/
+    PlasmaActivationFeedback *createPlasmaActivationFeedback(quint32 name, quint32 version, QObject *parent = nullptr);
     /**
      * Creates a PlasmaVirtualDesktopManagement and sets it up to manage the interface identified by
      * @p name and @p version.
@@ -873,38 +752,6 @@ public:
      * @since 5.4
      **/
     PlasmaWindowManagement *createPlasmaWindowManagement(quint32 name, quint32 version, QObject *parent = nullptr);
-    /**
-     * Creates an Idle and sets it up to manage the interface identified by
-     * @p name and @p version.
-     *
-     * Note: in case @p name is invalid or isn't for the org_kde_kwin_idle interface,
-     * the returned Idle will not be valid. Therefore it's recommended to call
-     * isValid on the created instance.
-     *
-     * @param name The name of the org_kde_kwin_idle interface to bind
-     * @param version The version or the org_kde_kwin_idle interface to use
-     * @param parent The parent for Idle
-     *
-     * @returns The created Idle.
-     * @since 5.4
-     **/
-    Idle *createIdle(quint32 name, quint32 version, QObject *parent = nullptr);
-    /**
-     * Creates a RemoteAccessManager and sets it up to manage the interface identified by
-     * @p name and @p version.
-     *
-     * Note: in case @p name is invalid or isn't for the org_kde_kwin_remote_access_manager interface,
-     * the returned RemoteAccessManager will not be valid. Therefore it's recommended to call
-     * isValid on the created instance.
-     *
-     * @param name The name of the org_kde_kwin_remote_access_manager interface to bind
-     * @param version The version or the org_kde_kwin_remote_access_manager interface to use
-     * @param parent The parent for RemoteAccessManager
-     *
-     * @returns The created RemoteAccessManager.
-     * @since 5.45
-     **/
-    RemoteAccessManager *createRemoteAccessManager(quint32 name, quint32 version, QObject *parent = nullptr);
     /**
      * Creates a FakeInput and sets it up to manage the interface identified by
      * @p name and @p version.
@@ -1001,22 +848,6 @@ public:
      * @since 5.5
      **/
     DpmsManager *createDpmsManager(quint32 name, quint32 version, QObject *parent = nullptr);
-    /**
-     * Creates a ServerSideDecorationManager and sets it up to manage the interface identified by
-     * @p name and @p version.
-     *
-     * Note: in case @p name is invalid or isn't for the org_kde_kwin_server_decoration_manager interface,
-     * the returned ServerSideDecorationManager will not be valid. Therefore it's recommended to call
-     * isValid on the created instance.
-     *
-     * @param name The name of the org_kde_kwin_server_decoration_manager interface to bind
-     * @param version The version or the org_kde_kwin_server_decoration_manager interface to use
-     * @param parent The parent for ServerSideDecorationManager
-     *
-     * @returns The created ServerSideDecorationManager.
-     * @since 5.6
-     **/
-    ServerSideDecorationManager *createServerSideDecorationManager(quint32 name, quint32 version, QObject *parent = nullptr);
     /**
      * Creates a TextInputManager and sets it up to manage the interface identified by
      * @p name and @p version.
@@ -1171,23 +1002,6 @@ public:
      **/
     AppMenuManager *createAppMenuManager(quint32 name, quint32 version, QObject *parent = nullptr);
 
-    /**
-     * Creates a ServerSideDecorationPaletteManager and sets it up to manage the interface identified by
-     * @p name and @p version.
-     *
-     * Note: in case @p name is invalid or isn't for the org_kde_kwin_appmenu_manager interface,
-     * the returned ServerSideDecorationPaletteManager will not be valid. Therefore it's recommended to call
-     * isValid on the created instance.
-     *
-     * @param name The name of the org_kde_kwin_server_decoration_palette_manager interface to bind
-     * @param version The version or the org_kde_kwin_server_decoration_palette_manager interface to use
-     * @param parent The parent for ServerSideDecorationPaletteManager
-     *
-     * @returns The created ServerSideDecorationPaletteManager.
-     * @since 5.42
-     **/
-    ServerSideDecorationPaletteManager *createServerSideDecorationPaletteManager(quint32 name, quint32 version, QObject *parent = nullptr);
-
     /**
      * Creates an XdgOutputManager and sets it up to manage the interface identified by
      * @p name and @p version.
@@ -1224,15 +1038,14 @@ public:
 
     ///@}
 
-
     /**
      * cast operator to the low-level Wayland @c wl_registry
      **/
-    operator wl_registry*();
+    operator wl_registry *();
     /**
      * cast operator to the low-level Wayland @c wl_registry
      **/
-    operator wl_registry*() const;
+    operator wl_registry *() const;
     /**
      * @returns access to the low-level Wayland @c wl_registry
      **/
@@ -1279,12 +1092,6 @@ Q_SIGNALS:
      * @param version The maximum supported version of the announced interface
      **/
     void outputAnnounced(quint32 name, quint32 version);
-    /**
-     * Emitted whenever a _wl_fullscreen_shell interface gets announced.
-     * @param name The name for the announced interface
-     * @param version The maximum supported version of the announced interface
-     **/
-    void fullscreenShellAnnounced(quint32 name, quint32 version);
     /**
      * Emitted whenever a wl_data_device_manager interface gets announced.
      * @param name The name for the announced interface
@@ -1292,14 +1099,6 @@ Q_SIGNALS:
      **/
     void dataDeviceManagerAnnounced(quint32 name, quint32 version);
 
-    void outputManagementAnnounced(quint32 name, quint32 version);
-    /**
-     * Emitted whenever a org_kde_kwin_outputdevice interface gets announced.
-     * @param name The name for the announced interface
-     * @param version The maximum supported version of the announced interface
-     * @since 5.5
-     **/
-    void outputDeviceAnnounced(quint32 name, quint32 version);
     /**
      * Emitted whenever a org_kde_plasma_shell interface gets announced.
      * @param name The name for the announced interface
@@ -1307,6 +1106,13 @@ Q_SIGNALS:
      * @since 5.4
      **/
     void plasmaShellAnnounced(quint32 name, quint32 version);
+    /**
+     * Emitted whenever a org_kde_plasma_activation_feedback interface gets announced.
+     * @param name The name for the announced interface
+     * @param version The maximum supported version of the announced interface
+     * @since 5.83
+     **/
+    void plasmaActivationFeedbackAnnounced(quint32 name, quint32 version);
     /**
      * Emitted whenever a org_kde_plasma_virtual_desktop_management interface gets announced.
      * @param name The name for the announced interface
@@ -1321,20 +1127,6 @@ Q_SIGNALS:
      * @since 5.4
      **/
     void plasmaWindowManagementAnnounced(quint32 name, quint32 version);
-    /**
-     * Emitted whenever a org_kde_kwin_idle interface gets announced.
-     * @param name The name for the announced interface
-     * @param version The maximum supported version of the announced interface
-     * @since 5.4
-     **/
-    void idleAnnounced(quint32 name, quint32 version);
-    /**
-     * Emitted whenever a org_kde_kwin_remote_access_manager interface gets announced.
-     * @param name The name for the announced interface
-     * @param version The maximum supported version of the announced interface
-     * @since 5.45
-     **/
-    void remoteAccessManagerAnnounced(quint32 name, quint32 version);
     /**
      * Emitted whenever a org_kde_kwin_fake_input interface gets announced.
      * @param name The name for the announced interface
@@ -1377,13 +1169,6 @@ Q_SIGNALS:
      * @since 5.5
      **/
     void dpmsAnnounced(quint32 name, quint32 version);
-    /**
-     * Emitted whenever a org_kde_kwin_server_decoration_manager interface gets announced.
-     * @param name The name for the announced interface
-     * @param version The maximum supported version of the announced interface
-     * @since 5.6
-     **/
-    void serverSideDecorationManagerAnnounced(quint32 name, quint32 version);
     /**
      * Emitted whenever a wl_text_input_manager interface gets announced.
      * @param name The name for the announced interface
@@ -1467,14 +1252,6 @@ Q_SIGNALS:
      */
     void appMenuAnnounced(quint32 name, quint32 version);
 
-    /**
-     * Emitted whenever a org_kde_kwin_server_decoration_palette_manager interface gets announced.
-     * @param name The name for the announced interface
-     * @param version The maximum supported version of the announced interface
-     * @since 5.42
-     */
-    void serverSideDecorationPaletteManagerAnnounced(quint32 name, quint32 version);
-
     /**
      * Emitted whenever a zxdg_output_v1 interface gets announced.
      * @param name The name for the announced interface
@@ -1535,34 +1312,23 @@ Q_SIGNALS:
      * @param name The name for the removed interface
      **/
     void outputRemoved(quint32 name);
-    /**
-     * Emitted whenever a _wl_fullscreen_shell interface gets removed.
-     * @param name The name for the removed interface
-     **/
-    void fullscreenShellRemoved(quint32 name);
     /**
      * Emitted whenever a wl_data_device_manager interface gets removed.
      * @param name The name for the removed interface
      **/
     void dataDeviceManagerRemoved(quint32 name);
-    /**
-     * Emitted whenever a org_kde_kwin_outputmanagement interface gets removed.
-     * @param name The name for the removed interface
-     * @since 5.5
-     **/
-    void outputManagementRemoved(quint32 name);
-    /**
-     * Emitted whenever a org_kde_kwin_outputdevice interface gets removed.
-     * @param name The name for the removed interface
-     * @since 5.5
-     **/
-    void outputDeviceRemoved(quint32 name);
     /**
      * Emitted whenever a org_kde_plasma_shell interface gets removed.
      * @param name The name for the removed interface
      * @since 5.4
      **/
     void plasmaShellRemoved(quint32 name);
+    /**
+     * Emitted whenever a org_kde_plasma_activation_feedback interface gets removed.
+     * @param name The name for the removed interface
+     * @since 5.83
+     **/
+    void plasmaActivationFeedbackRemoved(quint32 name);
     /**
      * Emitted whenever a org_kde_plasma_virtual_desktop_management interface gets removed.
      * @param name The name for the removed interface
@@ -1575,18 +1341,6 @@ Q_SIGNALS:
      * @since 5.4
      **/
     void plasmaWindowManagementRemoved(quint32 name);
-    /**
-     * Emitted whenever a org_kde_kwin_idle interface gets removed.
-     * @param name The name for the removed interface
-     * @since 5.4
-     **/
-    void idleRemoved(quint32 name);
-    /**
-     * Emitted whenever a org_kde_kwin_remote_access_manager interface gets removed.
-     * @param name The name for the removed interface
-     * @since 5.45
-     **/
-    void remoteAccessManagerRemoved(quint32 name);
     /**
      * Emitted whenever a org_kde_kwin_fake_input interface gets removed.
      * @param name The name for the removed interface
@@ -1623,12 +1377,6 @@ Q_SIGNALS:
      * @since 5.5
      **/
     void dpmsRemoved(quint32 name);
-    /**
-     * Emitted whenever a org_kde_kwin_server_decoration_manager interface gets removed.
-     * @param name The name for the removed interface
-     * @since 5.6
-     **/
-    void serverSideDecorationManagerRemoved(quint32 name);
     /**
      * Emitted whenever a wl_text_input_manager interface gets removed.
      * @param name The name for the removed interface
@@ -1700,13 +1448,6 @@ Q_SIGNALS:
      **/
     void appMenuRemoved(quint32 name);
 
-    /**
-     * Emitted whenever a org_kde_kwin_server_decoration_palette_manager gets removed.
-     * @param name The name of the removed interface
-     * @since 5.42
-     **/
-    void serverSideDecorationPaletteManagerRemoved(quint32 name);
-
     /**
      * Emitted whenever a zxdg_output_v1 gets removed.
      * @param name The name of the removed interface
